@@ -1,7 +1,6 @@
-require "numru/advanceddcl"
+require "numru/dcl"
 require "numru/netcdf"
 include NumRu
-include AdvancedDCL
 include NMath
 
 ## < create a sample netcdf file >
@@ -49,15 +48,17 @@ def draw_graph
    file.close
 
    #DCL.swlset('ldump',1)
-   Dev.open
-   Frame.new
-   Fig.inclpoint(x, y)
-   Axis.draw
-   Tone.set("lsoftf",false)
-   Tone.gtlb(z, -20)  # set the number of levels
-   Tone.draw(z, "ltone"=>true)
-   Contour.draw(z)
-   Dev.close
+   DCL.gropn(1)
+   DCL.grfrm
+   DCL.usspnt(x, y)
+   DCL.uspfit
+   DCL.usdaxs
+   DCL.sglset("lsoftf",false)
+   DCL.uegtlb(z, -20)  # set the number of levels
+   DCL.uelset("ltone",true)
+   DCL.uetone(z)
+   DCL.udcntz(z)
+   DCL.grcls
 end
 
 ###(main)###
