@@ -160,23 +160,19 @@ file.redef
 
 copy_byte = string.copy(byte_vara) 
 copy_byte.put([0,20],"byte") 
-copy_byte = copy_byte.name=("min to max of byte_vara")
+copy_byte.name="new_name"
 
 copy_byte2 = copy_byte
 (copy_byte2 == copy_byte)
 
-
 copy_sint = string.copy(sint_vara)
 copy_sint.put("%%%%%")
 copy_int = string.copy(int_vara)
 copy_int.put([0,60],"int")
-copy_int = copy_int.name= "min to max of int_vara"
 copy_sfloat = string.copy(sfloat_vara)
 copy_sfloat.put([0.01,5.5],"sfloat")
-copy_sfloat = copy_sfloat.name= "min to max of float_vara"
 copy_float = string.copy(float_vara)
 copy_float.put([0.0001,5.5555],"float")
-copy_float = copy_float.name= "min_to max of double_vara"
 file.enddef
 nm = copy_byte.name
 att0 = string.get
